@@ -66,16 +66,15 @@ def _check_libs():
         import gi
         gi.require_version('Gst', '1.0')
         gi.require_version('Gtk', '3.0')
-        gi.require_version('GConf', '2.0')
-        from gi.repository import GObject
+        from gi.repository import GLib
         # force GIL creation - see https://bugzilla.gnome.org/show_bug.cgi?id=710447
         import threading
         threading.Thread(target=lambda: None).start()
-        GObject.threads_init()
+        GLib.threads_init()
         from gi.repository import Gst
         Gst.init(None)
         from gi.repository import Gtk, Gdk
-        from gi.repository import GLib
+
     except (ImportError, ValueError) as error:
         print(('%s needs GTK >= 3.0 (Error: "%s")' % (NAME, error)))
         sys.exit(1)
