@@ -1,9 +1,9 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # SoundConverter - GNOME application for converting between audio formats.
 # Copyright 2004 Lars Wirzenius
-# Copyright 2005-2012 Gautier Portet
+# Copyright 2005-2017 Gautier Portet
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,21 +21,22 @@
 
 
 import sys
-import gobject
+import gi
 import time
-from soundfile import SoundFile
-import error
+from gi.repository import GLib
+
+from soundconverter.soundfile import SoundFile
+from soundconverter import error
 from soundconverter.settings import settings
-from gstreamer import TagReader
-from namegenerator import TargetNameGenerator
-from queue import TaskQueue
-from gstreamer import Converter
-from fileoperations import unquote_filename
+from soundconverter.gstreamer import TagReader
+from soundconverter.namegenerator import TargetNameGenerator
+from soundconverter.queue import TaskQueue
+from soundconverter.gstreamer import Converter
+from soundconverter.fileoperations import unquote_filename
 
 def cli_tags_main(input_files):
     error.set_error_handler(error.ErrorPrinter())
-    loop = gobject.MainLoop()
-    gobject.threads_init()
+    loop = GLib.MainLoop()
     context = loop.get_context()
     for input_file in input_files:
         input_file = SoundFile(input_file)
@@ -49,7 +50,7 @@ def cli_tags_main(input_files):
             
         if not settings['quiet']:
             for key in sorted(input_file.tags):
-                print('     %s: %s' % (key, input_file.tags[key]))
+                print(('     %s: %s' % (key, input_file.tags[key])))
 
 
 class CliProgress:
@@ -70,8 +71,7 @@ class CliProgress:
 
 
 def cli_convert_main(input_files):
-    loop = gobject.MainLoop()
-    gobject.threads_init()
+    loop = GLib.MainLoop()
     context = loop.get_context()
     error.set_error_handler(error.ErrorPrinter())
 
@@ -88,6 +88,7 @@ def cli_convert_main(input_files):
         input_file = SoundFile(input_file)
         output_name = generator.get_target_name(input_file)
         c = Converter(input_file, output_name, output_type)
+        c.overwrite = True
         c.init()
         c.start()
         while c.running:
@@ -99,7 +100,7 @@ def cli_convert_main(input_files):
             progress.show('%s: %s' % (unquote_filename(c.sound_file.filename[-65:]), percent ))
             time.sleep(0.01)
             context.iteration(True)
-        print
+        print()
 
     previous_filename = None
     
