@@ -25,10 +25,10 @@ from urllib.parse import urlparse
 from gettext import gettext as _
 
 import gi
-from gi.repository import Gst, Gtk, GObject, GConf, Gio
+from gi.repository import Gst, Gtk, GLib, GObject, Gio
 
 from soundconverter.fileoperations import vfs_encode_filename, file_encode_filename
-from soundconverter.fileoperations import unquote_filename, vfs_makedirs, vfs_unlink
+from soundconverter.fileoperations import unquote_filename, vfs_unlink
 from soundconverter.fileoperations import vfs_rename
 from soundconverter.fileoperations import vfs_exists
 from soundconverter.fileoperations import beautify_uri
@@ -66,25 +66,30 @@ _GCONF_PROFILE_LIST_PATH = "/system/gstreamer/1.0/audio/global/profile_list"
 audio_profiles_list = []
 audio_profiles_dict = {}
 
-_GCONF = GConf.Client.get_default()
-profiles = _GCONF.all_dirs(_GCONF_PROFILE_LIST_PATH)
-for name in profiles:
-    if _GCONF.get_bool(_GCONF_PROFILE_PATH + name + "/active"):
-        # get profile
-        description = _GCONF.get_string(_GCONF_PROFILE_PATH + name + "/name")
-        extension = _GCONF.get_string(_GCONF_PROFILE_PATH + name + "/extension")
-        pipeline = _GCONF.get_string(_GCONF_PROFILE_PATH + name + "/pipeline")
-        # check profile validity
-        if not extension or not pipeline:
-            continue
-        if not description:
-            description = extension
-        if description in audio_profiles_dict:
-            continue
-            # store
-        profile = description, extension, pipeline
-        audio_profiles_list.append(profile)
-        audio_profiles_dict[description] = profile
+try:
+    gi.require_version('GConf', '2.0')
+    from gi.repository import GConf
+    _GCONF = GConf.Client.get_default()
+    profiles = _GCONF.all_dirs(_GCONF_PROFILE_LIST_PATH)
+    for name in profiles:
+        if _GCONF.get_bool(_GCONF_PROFILE_PATH + name + "/active"):
+            # get profile
+            description = _GCONF.get_string(_GCONF_PROFILE_PATH + name + "/name")
+            extension = _GCONF.get_string(_GCONF_PROFILE_PATH + name + "/extension")
+            pipeline = _GCONF.get_string(_GCONF_PROFILE_PATH + name + "/pipeline")
+            # check profile validity
+            if not extension or not pipeline:
+                continue
+            if not description:
+                description = extension
+            if description in audio_profiles_dict:
+                continue
+                # store
+            profile = description, extension, pipeline
+            audio_profiles_list.append(profile)
+            audio_profiles_dict[description] = profile
+except ImportError:
+    pass
 
 required_elements = ('decodebin', 'fakesink', 'audioconvert', 'typefind', 'audiorate')
 for element in required_elements:
@@ -101,30 +106,41 @@ print('  using gio')
 user_canceled_codec_installation = False
 
 encoders = (
-    ('flacenc', 'FLAC'),
-    ('wavenc', 'WAV'),
-    ('vorbisenc', 'Ogg Vorbis'),
-    ('oggmux', 'Ogg Vorbis'),
-    ('id3mux', 'MP3 tags'),
-    ('xingmux', 'VBR tags'),
-    ('lamemp3enc', 'MP3'),
-    ('faac', 'AAC'),
-    ('mp4mux', 'AAC'),
-    ('opusenc', 'Opus'),
+    ('flacenc', 'FLAC', 'flac-enc'),
+    ('wavenc', 'WAV', 'wav-enc'),
+    ('vorbisenc', 'Ogg Vorbis', 'vorbis-enc'),
+    ('oggmux', 'Ogg Vorbis', 'vorbis-mux'),
+    ('id3mux', 'MP3 tags', 'mp3-id-tags'),
+    ('id3v2mux', 'MP3 tags', 'mp3-id-tags'),
+    ('xingmux', 'VBR tags', 'mp3-vbr-tags'),
+    ('lamemp3enc', 'MP3', 'mp3-enc'),
+    ('faac', 'AAC', 'aac-enc'),
+    ('avenc_aac', 'AAC', 'aac-enc'),
+    ('mp4mux', 'AAC', 'aac-mux'),
+    ('opusenc', 'Opus', 'opus-enc'),
 )
 
 available_elements = set()
+functions = dict()
 
-for encoder, name in encoders:
+for encoder, name, function in encoders:
     have_it = bool(Gst.ElementFactory.find(encoder))
     if have_it:
         available_elements.add(encoder)
     else:
-        print(('  "%s" gstreamer element not found'
-               ', disabling %s output.' % (encoder, name)))
+        print('  %s gstreamer element not found' % encoder)
+    function += '_' + name
+    functions[function] = functions.get(function) or have_it
+
+for function in sorted(functions):
+    if not functions[function]:
+        print('  disabling %s output.' % function.split('_')[1])
 
 if 'oggmux' not in available_elements:
     available_elements.discard('vorbisenc')
+if 'mp4mux' not in available_elements:
+    available_elements.discard('faac')
+    available_elements.discard('avenc_aac')
 
 
 class Pipeline(BackgroundTask):
@@ -198,7 +214,7 @@ class Pipeline(BackgroundTask):
             self.done()
             return
         self.done()
-        show_error('Error', 'failed to install plugins: %s' % GObject.markup_escape_text(str(result)))
+        show_error('Error', 'failed to install plugins: %s' % GLib.markup_escape_text(str(result)))
 
     def on_error(self, error):
         self.error = error
@@ -264,7 +280,7 @@ class Pipeline(BackgroundTask):
 
                 self.parsed = True
 
-            except GObject.GError as e:
+            except GLib.GError as e:
                 show_error('GStreamer error when creating pipeline', str(e))
                 self.error = str(e)
                 self.eos = True
@@ -315,6 +331,10 @@ class TypeFinder(Pipeline):
         # since its caps would've been the same as decodebin's sink caps.
         self.add_signal('typefind', 'have-type', self.have_type)
 
+    def on_error(self, error):
+        self.error = error
+        log('ignored-error: %s (%s)' % (error, ' ! '.join(self.command)))
+
     def set_found_type_hook(self, found_type_hook):
         self.found_type_hook = found_type_hook
     
@@ -474,7 +494,7 @@ class TagReader(Decoder):
         Pipeline.finished(self)
         self.sound_file.tags_read = True
         if self.found_tag_hook:
-            GObject.idle_add(self.found_tag_hook, self)
+            GLib.idle_add(self.found_tag_hook, self)
 
 
 class Converter(Decoder):
@@ -630,11 +650,15 @@ class Converter(Decoder):
         if 'id3mux' in available_elements:
             # add tags
             cmd += '! id3mux '
+        elif 'id3v2mux' in available_elements:
+            # add tags
+            cmd += '! id3v2mux '
 
         return cmd
 
     def add_aac_encoder(self):
-        return 'faac bitrate=%s ! mp4mux' % (self.aac_quality * 1000)
+        encoder = 'faac' if 'faac' in available_elements else 'avenc_aac'
+        return '%s bitrate=%s ! mp4mux' % (encoder, self.aac_quality * 1000)
 
     def add_opus_encoder(self):
         return 'opusenc bitrate=%s bitrate-type=vbr bandwidth=auto ! oggmux' % (self.opus_quality * 1000)
