@@ -69,7 +69,7 @@ def gtk_iteration():
 def gtk_sleep(duration):
     start = time.time()
     while time.time() < start + duration:
-        time.sleep(0.010)
+        time.sleep(0.01)
         gtk_iteration()
 
 
@@ -111,7 +111,7 @@ class MsgAreaErrorDialog_:
 
 
     def show_exception(self, exception):
-        self.show('<b>%s</b>' % GObject.markup_escape_text(exception.primary),
+        self.show('<b>%s</b>' % GLib.markup_escape_text(exception.primary),
                     exception.secondary)
 
 
@@ -183,21 +183,15 @@ class FileList:
         return [i[1] for i in self.sortedmodel]
 
     def update_progress(self):
-        gtk_iteration()
-        if self.files_to_add is None:
-            return False
-        if self.files_to_add:
-            fraction = float(len(self.model)) / self.files_to_add
-            self.window.progressbarstatus.set_fraction(fraction)
-        else:
+        if self.files_to_add is not None:
             self.window.progressbarstatus.pulse()
-        return True
+            return True
+        return False
 
     def found_type(self, sound_file, mime):
-        assert False
-        debug('found_type', sound_file.filename)
-        self.append_file(sound_file)
-        self.window.set_sensitive()
+        ext = os.path.splitext(sound_file.filename)[1]
+        debug('mime:', ext, mime)
+        self.extensions[ext] = mime
 
     @idle
     def add_uris(self, uris, base=None, extensions=None):
@@ -206,7 +200,7 @@ class FileList:
         self.window.set_status(_('Scanning files...'))
         self.window.progressbarstatus.show()
         self.files_to_add = 0
-        GObject.timeout_add(100, self.update_progress)
+        GLib.timeout_add(100, self.update_progress)
 
         for uri in uris:
             gtk_iteration()
@@ -247,11 +241,32 @@ class FileList:
             base += '/'
 
         scan_t = time.time()
-        log('adding: %d files' % len(files))
+        log('analysing file extensions')
         self.files_to_add = len(files)
         self.window.set_status(_('Adding Files...'))
+        
+        self.extensions = {}
+        extensions = {}
         for f in files:
-            #gtk_iteration()
+            extensions[os.path.splitext(f)[1]] = f
+        for ext, filename in extensions.items():
+            sound_file = SoundFile(filename, base)
+            typefinder = TypeFinder(sound_file)
+            typefinder.set_found_type_hook(self.found_type)
+            self.typefinders.add_task(typefinder)
+
+        self.typefinders.queue_ended = self.typefinder_queue_ended
+        self.typefinders.start()
+
+        while(self.typefinders.running):
+            gtk_iteration()
+            time.sleep(0.1)
+
+        log('adding: %d files' % len(files))
+        for f in files:
+            ext = os.path.splitext(f)[1]
+            if ext not in self.extensions:
+                continue
             sound_file = SoundFile(f, base)
             if sound_file.uri in self.filelist:
                 log('file already present: \'%s\'' % sound_file.uri)
@@ -274,7 +289,7 @@ class FileList:
         self.typefinders.abort()
 
     def format_cell(self, sound_file):
-        return '%s' % GObject.markup_escape_text(unquote_filename(
+        return '%s' % GLib.markup_escape_text(unquote_filename(
                                                   sound_file.filename))
 
     def set_row_progress(self, number, progress=None, text=None):
@@ -541,7 +556,7 @@ class PreferencesDialog(GladeWindow):
         cell = Gtk.CellRendererText()
         self.resample_rate.pack_start(cell, True)
         self.resample_rate.add_attribute(cell, 'text', 0)
-        rates = [8000, 11025, 22050, 44100, 48000, 96000]
+        rates = [8000, 11025, 16000, 22050, 32000, 44100, 48000, 96000, 128000]
         rate = self.settings.get_int('resample-rate')
         try:
             idx = rates.index(rate)
@@ -609,7 +624,7 @@ class PreferencesDialog(GladeWindow):
         sound_file.tags.update({'disc-number': 2, 'disc-count': 9})
         sound_file.tags.update(locale_patterns_dict)
 
-        s = GObject.markup_escape_text(beautify_uri(
+        s = GLib.markup_escape_text(beautify_uri(
                         self.generate_filename(sound_file, for_display=True)))
         p = 0
         replaces = []
@@ -948,10 +963,9 @@ class PreferencesDialog(GladeWindow):
         self.update_example()
 
     def on_resample_rate_changed(self, combobox):
-        model = combobox.get_model()
-        iter = combobox.get_active_iter()
-        changeto =  model.get_value(iter, 0)
-        self.settings.set_int('resample-rate', int(changeto))
+        selected = combobox.get_active()
+        rates = [8000, 11025, 16000, 22050, 32000, 44100, 48000, 96000, 128000]
+        self.settings.set_int('resample-rate', rates[selected])
 
     def on_resample_toggle(self, rstoggle):
         self.settings.set_boolean('output-resample', rstoggle.get_active())
@@ -1100,9 +1114,9 @@ class SoundConverterWindow(GladeWindow):
         self.combo.set_active(0)
         self.addfolderchooser.set_extra_widget(self.combo)
 
-        self.aboutdialog.set_property('name', NAME)
-        self.aboutdialog.set_property('version', VERSION)
-        self.aboutdialog.set_transient_for(self.widget)
+        #self.aboutdialog.set_property('name', NAME)
+        #self.aboutdialog.set_property('version', VERSION)
+        #self.aboutdialog.set_transient_for(self.widget)
 
         self.converter = ConverterQueue(self)
 
@@ -1244,7 +1258,7 @@ class SoundConverterWindow(GladeWindow):
 
     def do_convert(self):
         self.pulse_progress = -1
-        GObject.timeout_add(100, self.on_progress)
+        GLib.timeout_add(100, self.on_progress)
         self.progressbar.set_text(_('Preparing conversion...'))
         files = self.filelist.get_files()
         total = len(files)
@@ -1305,7 +1319,7 @@ class SoundConverterWindow(GladeWindow):
         about.set_property('version', VERSION)
         about.set_transient_for(self.widget)
         #TODO: about.set_property('translator_credits', TRANSLATORS)
-        about.show()
+        about.run()
 
     def on_aboutdialog_response(self, *args):
         self.aboutdialog.hide()
@@ -1401,6 +1415,9 @@ win = None
 def gui_main(name, version, gladefile, input_files):
     global NAME, VERSION
     NAME, VERSION = name, version
+    GLib.set_application_name(name)
+    GLib.set_prgname(name)
+
     builder = Gtk.Builder()
     builder.set_translation_domain(name.lower())
     builder.add_from_file(gladefile)
