@@ -1,9 +1,9 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # SoundConverter - GNOME application for converting between audio formats.
 # Copyright 2004 Lars Wirzenius
-# Copyright 2005-2012 Gautier Portet
+# Copyright 2005-2017 Gautier Portet
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 
 # logging & debugging
 
-from settings import settings
-
+from .settings import settings
+from gi.repository import GLib
 
 def log(*args):
     """
@@ -30,7 +30,7 @@ def log(*args):
     Can be disabled with 'quiet' option
     """
     if not settings['quiet']:
-        print( ' '.join([str(msg) for msg in args]) )
+        print(( ' '.join([str(msg) for msg in args]) ))
 
 
 def debug(*args):
@@ -39,4 +39,9 @@ def debug(*args):
     Only when activated by 'debug' option
     """
     if settings['debug']:
-        print( ' '.join([str(msg) for msg in args]) )
+        print(( ' '.join([str(msg) for msg in args]) ))
+
+def idle(func):
+    def callback(*args, **kwargs):
+        GLib.idle_add(func, *args, **kwargs)
+    return callback
